﻿class LivresController < ApplicationController

##### La structure est identique à celle de auteurs. Voir ce dernier contrôleur pour des commentaires complets. Certains sont spécifiques à ce présent contrôleur.

##### Remise à blanc des erreurs avant affichage de l'écran de modif/ajout
before_action only: [:ajout, :modif, :controle] do
  	flash[:meserr]=""
end



##### Liste des livres
def liste

	# Calculer la requete sql de sélection en combinant les 3 critères auteur, titre et catégorie
	rqsel=""
	rqand=""
	
	# critère auteur
	if !(cookies[:livaut] =="" or cookies[:livaut].nil?) then
		rqsel=rqsel + "auteur_id = " + cookies[:livaut]
		rqand=" and "
	end

	# critère titre
	if !(cookies[:livtit] ==""  or cookies[:livtit].nil?) then
		rqsel=rqsel + rqand + "livtit like '%" + cookies[:livtit] +"%'"
		rqand=" and "
	end

	# critère catégorie
	if !(cookies[:livcat]==""  or cookies[:livcat].nil?) then
		rqsel=rqsel + rqand + "livcat = " + cookies[:livcat]
		rqand=" and "
	end


	# Lancer la requete qui joint les auteurs et les catégories aux livres, selon qu'il y a une sélection ou non
	if rqsel==="" then
		@liv=Livre.joins(:auteur).joins(:categorie).order("auteurs.autabr ASC, livres.livtit ASC")
	else
		@liv=Livre.where(rqsel).joins(:auteur).joins(:categorie).order("auteurs.autabr ASC, livres.livtit ASC")
	end

end



##### Appel du formulaire d'ajout d'un livre
def ajout

	# créer les instances des tables nécessaires
	@newliv=Livre.new
	@newaut=Auteur.new
	@newcat=Categorie.new
	render :modif

end



##### Validation de l'ajout d'un livre
def ajoutvalid

	# pour debug  
	# @newliv = Livre.new
	# @newaut = Auteur.new
	# @newcat = Categorie.new
	# flash[:meserr]=params
	#  render :modif
	#  return
	
	
	# paramètre reçu du formulaire d'ajout
	# ancienne version : l'id de l'auteur est saisi dans un champ texte : il est inclus dans livre puis auteur
	# {"utf8"=>"?", "authenticity_token"=>"x475js/GaFWnzGevWoFicm+CIsLbc0TySGRt/8nF9gI=", "livre"=>{"id"=>"", "auteur"=>{"autnom"=>"1"}, "livtit"=>"Nouveau titre"}, "commit"=>"Valider", "action"=>"ajoutvalid", "controller"=>"livres"}
	
	# l'id de l'auteur est saisi via une combo : il est inclus dans auteur, au meme niveau que livre (voir différence avec ligne précédente)
	# {"utf8"=>"?", "authenticity_token"=>"vn2h4XV0F5s3t4UVvtcKZEvqVbMbCfm6H8+V52ShaeI=", "livre"=>{"id"=>"", "livtit"=>"Science F."}, "auteur"=>{"auteur_id"=>"51"}, "commit"=>"Valider", "action"=>"ajoutvalid", "controller"=>"livres"}

	### Initialiser la zone de réception des données
	@newliv=Livre.new
	@newaut=Auteur.new
	@newcat=Categorie.new
	
	### Controler les données
	if controle == 1 then
		
		# afficher directement la vue sans repasser par l'action ajout qui réinitialise @newaut
		render :modif
		return

	else
	
		# Ecriture par create
	
		# avec champ de saisie id auteur : l'id est dans livre puis auteur
		#Livre.create(:auteur_id => params[:livre][:auteur][:id], :livtit=>params[:livre][:livtit])
		
		# avec liste deroulante auteur : l'id est directement dans auteur
		Livre.create(:auteur_id => params[:auteur][:auteur_id], :livtit=>params[:livre][:livtit], :livcat => params[:categorie][:livcat])

		# Réafficher la liste
		redirect_to lister_les_livres_path

	end

end



##### Appel du formulaire de modification d'un livre
def modif

	@newliv = Livre.find(params[:id])

	# rechercher l'auteur du livre lu
	@newaut = Auteur.find(@newliv.auteur_id)

	# rechercher la catégorie du livre lu
	@newcat = Categorie.find(@newliv.livcat)

end



##### Validation de la modification d'un livre
def modifvalid

	### paramètre reçu du formulaire de modif
	# {"utf8"=>"?", "authenticity_token"=>"PcHJjk2fXjAPs9QJsD1qbbmBQTWFtkvKWdrt6gDdWTA=", "livre"=>{"id"=>"19", "livtit"=>"asim off 2233"}, "auteur"=>{"auteur_id"=>"62"}, "commit"=>"Valider", "action"=>"modifvalid", "controller"=>"livres"}

	### Initialiser la zone de réception des données
	@newliv=Livre.find(params[:livre][:id])
	@newaut=Auteur.new
	@newcat=Categorie.new

	### Controler les données
	if controle == 1 then
		
		# afficher directement la vue sans repasser par l'action modif qui recharge @newaut à l'initial
		render :modif
		return

	else

		@newliv.save
		redirect_to lister_les_livres_path

	end


	

end



##### Controle des données

def controle

	# Affecter les données du formulaire à la zone fichier
	@newliv[:auteur_id]= params[:auteur][:auteur_id]
	@newliv[:livtit]= params[:livre][:livtit]
	@newliv[:livcat]= params[:categorie][:livcat]

	### Controler les données
	inderr=0

	# titre obligatoire
	if (@newliv[:livtit]==="" && inderr ==0) then
		flash[:meserr]="Et le titre ?"
		inderr=1
	end

	# autres controles ...

	x=inderr

end



##### Validation de la suppression d'un livre
def supprvalid
	
	### Suppression. Le param recu a la forme {"action"=>"supprvalid", "controller"=>"auteurs", "format"=>"6"}  
	Livre.delete(params[:format])

	### Réafficher la liste
	redirect_to lister_les_livres_path

end



##### Saisie des critères de sélection des livres
def recherche
	
	render :recherche # pourrait être omis car le nom de la vue = nom de l'action

end



##### Validation des critères de sélection des livres
def recherchevalid
	
	# contenu du paramètre retourné
	# {"utf8"=>"?", "authenticity_token"=>"PcHJjk2fXjAPs9QJsD1qbbmBQTWFtkvKWdrt6gDdWTA=", "auteur"=>{"xauteur_id"=>"2"}, "xtitre"=>"abcdef", "commit"=>"Valider", "action"=>"recherchevalid", "controller"=>"livres"}

	#pour debug
	#flash[:meserr]=params
	#render :recherche
	#return
	
	# sauvegarder les paramètres
	cookies[:livaut]=params[:auteur][:xauteur_id]
	cookies[:livtit]=params[:xtitre]
	cookies[:livcat]=params[:categorie][:xlivcat]
	
	# afficher la liste
	redirect_to lister_les_livres_path

end



##### Effacement des critères de sélection
def rechercheraz
	
	# remettre à blanc les paramètres de recherche
	cookies[:livaut]=""
	cookies[:livtit]=""
	cookies[:livcat]=""

	# puis actualiser l'écran de saisie des paramètres
	redirect_to selectionner_des_livres_path

end



end


